@@ -1,6 +1,6 @@
 package Courriel::Role::Part;
 BEGIN {
-  $Courriel::Role::Part::VERSION = '0.05';
+  $Courriel::Role::Part::VERSION = '0.06';
 }
 
 use strict;
@@ -40,12 +40,6 @@ has content_type => (
     handles   => [qw( mime_type charset )],
 );
 
-has encoding => (
-    is      => 'ro',
-    isa     => NonEmptyStr,
-    default => '8bit',
-);
-
 sub as_string {
     my $self = shift;
 
